# Autogenerated by nbdev

d = { 'settings': { 'branch': 'main',
                'doc_baseurl': '/ssfMiscUtilities',
                'doc_host': 'https://SantiagoSanchezF.github.io',
                'git_url': 'https://github.com/SantiagoSanchezF/ssfMiscUtilities',
                'lib_path': 'ssfMiscUtilities'},
  'syms': { 'ssfMiscUtilities.core': {'ssfMiscUtilities.core.foo': ('core.html#foo', 'ssfMiscUtilities/core.py')},
            'ssfMiscUtilities.generic': { 'ssfMiscUtilities.generic.dump_pickle': ( 'generic.html#dump_pickle',
                                                                                    'ssfMiscUtilities/generic.py'),
                                          'ssfMiscUtilities.generic.fprint': ('generic.html#fprint', 'ssfMiscUtilities/generic.py'),
                                          'ssfMiscUtilities.generic.lmap': ('generic.html#lmap', 'ssfMiscUtilities/generic.py'),
                                          'ssfMiscUtilities.generic.load_pickle': ( 'generic.html#load_pickle',
                                                                                    'ssfMiscUtilities/generic.py'),
                                          'ssfMiscUtilities.generic.mmap': ('generic.html#mmap', 'ssfMiscUtilities/generic.py'),
                                          'ssfMiscUtilities.generic.sed_script': ('generic.html#sed_script', 'ssfMiscUtilities/generic.py'),
                                          'ssfMiscUtilities.generic.split_list': ( 'generic.html#split_list',
                                                                                   'ssfMiscUtilities/generic.py')},
            'ssfMiscUtilities.lsf_interactive': { 'ssfMiscUtilities.lsf_interactive.LSF': ( 'lsf_interactive.html#lsf',
                                                                                            'ssfMiscUtilities/lsf_interactive.py'),
                                                  'ssfMiscUtilities.lsf_interactive.LSF.__init__': ( 'lsf_interactive.html#lsf.__init__',
                                                                                                     'ssfMiscUtilities/lsf_interactive.py'),
                                                  'ssfMiscUtilities.lsf_interactive.LSF.clean': ( 'lsf_interactive.html#lsf.clean',
                                                                                                  'ssfMiscUtilities/lsf_interactive.py'),
                                                  'ssfMiscUtilities.lsf_interactive.LSF.retake': ( 'lsf_interactive.html#lsf.retake',
                                                                                                   'ssfMiscUtilities/lsf_interactive.py'),
                                                  'ssfMiscUtilities.lsf_interactive.LSF.update': ( 'lsf_interactive.html#lsf.update',
                                                                                                   'ssfMiscUtilities/lsf_interactive.py'),
                                                  'ssfMiscUtilities.lsf_interactive.get_result': ( 'lsf_interactive.html#get_result',
                                                                                                   'ssfMiscUtilities/lsf_interactive.py'),
                                                  'ssfMiscUtilities.lsf_interactive.lsf_job': ( 'lsf_interactive.html#lsf_job',
                                                                                                'ssfMiscUtilities/lsf_interactive.py'),
                                                  'ssfMiscUtilities.lsf_interactive.lsf_job.__init__': ( 'lsf_interactive.html#lsf_job.__init__',
                                                                                                         'ssfMiscUtilities/lsf_interactive.py'),
                                                  'ssfMiscUtilities.lsf_interactive.submit': ( 'lsf_interactive.html#submit',
                                                                                               'ssfMiscUtilities/lsf_interactive.py'),
                                                  'ssfMiscUtilities.lsf_interactive.update_status': ( 'lsf_interactive.html#update_status',
                                                                                                      'ssfMiscUtilities/lsf_interactive.py')}}}
